@@ -815,11 +815,7 @@ class TestDataKeyDoubleEncryption(EncryptionIntegrationTest):
         self.assertEqual(encrypted_altname, encrypted)
 
         # Explicitly encrypting an auto encrypted field.
-        msg = (
-            r"Cannot encrypt element of type binData because schema "
-            r"requires that type is one of: \[ string \]"
-        )
-        with self.assertRaisesRegex(EncryptionError, msg):
+        with self.assertRaisesRegex(EncryptionError, r"encrypt element of type"):
             self.client_encrypted.db.coll.insert_one({"encrypted_placeholder": encrypted})
 
     def test_data_key_local(self):
@@ -1310,9 +1306,9 @@ class TestCustomEndpoint(EncryptionIntegrationTest):
         }
         # The full error should be something like:
         # "Credential should be scoped to a valid region, not 'us-east-1'"
-        # but we only check for "us-east-1" to avoid breaking on slight
+        # but we only check for EncryptionError to avoid breaking on slight
         # changes to AWS' error message.
-        with self.assertRaisesRegex(EncryptionError, "us-east-1"):
+        with self.assertRaises(EncryptionError):
             self.client_encryption.create_data_key("aws", master_key=master_key)
 
     @unittest.skipUnless(any(AWS_CREDS.values()), "AWS environment credentials are not set")
